"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EdmGuid = void 0;
const constants_1 = require("../utils/constants");
const EntityProperty_1 = require("./EntityProperty");
class EdmGuid {
    constructor(value) {
        this.value = value;
        this.typedValue = EdmGuid.validate(value);
    }
    static validate(value) {
        if (typeof value !== "string") {
            throw TypeError(`Not a valid EdmGuid string.`);
        }
        // TODO: Check GUID string format
        return value;
    }
    toJsonPropertyValuePair(name) {
        return [name, this.typedValue];
    }
    toJsonPropertyValueString(name) {
        return `"${name}":${JSON.stringify(this.typedValue)}`;
    }
    toJsonPropertyTypePair(name, annotationLevel, isSystemProperty) {
        if (isSystemProperty) {
            throw RangeError(`EdmGuid type shouldn't be a system property.`);
        }
        if (annotationLevel === EntityProperty_1.AnnotationLevel.MINIMAL ||
            annotationLevel === EntityProperty_1.AnnotationLevel.FULL) {
            return [`${name}${constants_1.ODATA_TYPE}`, "Edm.Guid"];
        }
    }
    toJsonPropertyTypeString(name, annotationLevel, isSystemProperty) {
        const res = this.toJsonPropertyTypePair(name, annotationLevel, isSystemProperty);
        if (!res) {
            return;
        }
        const [key, value] = res;
        return `"${key}":"${value}"`;
    }
}
exports.EdmGuid = EdmGuid;
//# sourceMappingURL=EdmGuid.js.map